pub struct AbilityLevel {
pub level: i64,
pub rarity_id: AbilityRarityId,
pub required_shards: i64,
}Fields
level: i64rarity_id: AbilityRarityIdrequired_shards: i64Trait Implementations
Sourceimpl Clone for AbilityLevel
impl Clone for AbilityLevel
Sourcefn clone(&self) -> AbilityLevel
fn clone(&self) -> AbilityLevel
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AbilityLevel
impl Debug for AbilityLevel
Sourceimpl<'de> Deserialize<'de> for AbilityLevel
impl<'de> Deserialize<'de> for AbilityLevel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AbilityLevel
impl JsonSchema for AbilityLevel
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AbilityLevel
impl PartialEq for AbilityLevel
Sourceimpl Serialize for AbilityLevel
impl Serialize for AbilityLevel
Sourceimpl Tsify for AbilityLevel
impl Tsify for AbilityLevel
const DECL: &'static str = "export interface AbilityLevel {\n level: number;\n rarity_id: AbilityRarityId;\n required_shards: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for AbilityLevel
impl StructuralPartialEq for AbilityLevel