pub struct Projectile {
pub id: ProjectileId,
pub start_script: String,
pub script: String,
pub vfx: String,
}Fields
id: ProjectileIdstart_script: Stringscript: Stringvfx: StringTrait Implementations
Sourceimpl Clone for Projectile
impl Clone for Projectile
Sourcefn clone(&self) -> Projectile
fn clone(&self) -> Projectile
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Projectile
impl Debug for Projectile
Sourceimpl<'de> Deserialize<'de> for Projectile
impl<'de> Deserialize<'de> for Projectile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Projectile
impl JsonSchema for Projectile
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Projectile
impl PartialEq for Projectile
Sourceimpl Serialize for Projectile
impl Serialize for Projectile
Sourceimpl Tsify for Projectile
impl Tsify for Projectile
const DECL: &'static str = "export interface Projectile {\n id: ProjectileId;\n start_script: string;\n script: string;\n vfx: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Projectile
impl StructuralPartialEq for Projectile